@@ -4,7 +4,6 @@ from zope import schema
 from zope.interface import Interface
 from Products.CMFCore.utils import getToolByName
 from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm
-from zope.app.form.browser.itemswidgets import SelectWidget
 
 from zope.i18nmessageid import MessageFactory
 
@@ -24,8 +23,6 @@ class IButtonSettings(Interface):
     """Global settings for the transition button panel. Settings stored in the 
        Plone registry
     """
-    SelectWidget._messageNoValue = ("bottomRight", "Default")
-
     floating = schema.Bool(title=u'Floating button box.',
                                 description=u'Enable this option to make the transition button box float statically above the page',
                                 required=False,
@@ -41,17 +38,10 @@ class IButtonSettings(Interface):
                                 title=u'Floating Location',
                                 description=u'The location on screen where the transition button box will float. If floating is \
                                 disabled, this option does nothing.',
-                                default="bottomRight",
-                                required=True)
-
-    floatSpacing = schema.TextLine(title=u'Floating Spacing',
-                                description=u'The value (in pixels) of spacing between the button box, and the edge of the screen',
-                                default=u"10",
                                 required=False)
 
     EnabledTypes = schema.List(title=_(u"Enable content types."),
-                                description=u'The content types that the transition button box should appear on. If no \
-                                values are added, it is assumed that all content types are allowed.',
+                                description=u'The content types that the transition button box should appear on.',
                                 value_type=schema.Choice(source=u"plone.app.vocabularies.UserFriendlyTypes"),
                                 required=False,)
 
